#line 2 "wimaxasncp_dict.c"

#line 4 "wimaxasncp_dict.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer WimaxasncpDict_create_buffer
#define yy_delete_buffer WimaxasncpDict_delete_buffer
#define yy_flex_debug WimaxasncpDict_flex_debug
#define yy_init_buffer WimaxasncpDict_init_buffer
#define yy_flush_buffer WimaxasncpDict_flush_buffer
#define yy_load_buffer_state WimaxasncpDict_load_buffer_state
#define yy_switch_to_buffer WimaxasncpDict_switch_to_buffer
#define yyin WimaxasncpDictin
#define yyleng WimaxasncpDictleng
#define yylex WimaxasncpDictlex
#define yylineno WimaxasncpDictlineno
#define yyout WimaxasncpDictout
#define yyrestart WimaxasncpDictrestart
#define yytext WimaxasncpDicttext
#define yywrap WimaxasncpDictwrap
#define yyalloc WimaxasncpDictalloc
#define yyrealloc WimaxasncpDictrealloc
#define yyfree WimaxasncpDictfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE WimaxasncpDictrestart(WimaxasncpDictin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int WimaxasncpDictleng;

extern FILE *WimaxasncpDictin, *WimaxasncpDictout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up WimaxasncpDicttext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up WimaxasncpDicttext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via WimaxasncpDictrestart()), so that the user can continue scanning by
	 * just pointing WimaxasncpDictin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when WimaxasncpDicttext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int WimaxasncpDictleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow WimaxasncpDictwrap()'s to do buffer switches
 * instead of setting up a fresh WimaxasncpDictin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void WimaxasncpDictrestart (FILE *input_file  );
void WimaxasncpDict_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE WimaxasncpDict_create_buffer (FILE *file,int size  );
void WimaxasncpDict_delete_buffer (YY_BUFFER_STATE b  );
void WimaxasncpDict_flush_buffer (YY_BUFFER_STATE b  );
void WimaxasncpDictpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void WimaxasncpDictpop_buffer_state (void );

static void WimaxasncpDictensure_buffer_stack (void );
static void WimaxasncpDict_load_buffer_state (void );
static void WimaxasncpDict_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER WimaxasncpDict_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE WimaxasncpDict_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE WimaxasncpDict_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE WimaxasncpDict_scan_bytes (yyconst char *bytes,int len  );

void *WimaxasncpDictalloc (yy_size_t  );
void *WimaxasncpDictrealloc (void *,yy_size_t  );
void WimaxasncpDictfree (void *  );

#define yy_new_buffer WimaxasncpDict_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        WimaxasncpDictensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        WimaxasncpDictensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *WimaxasncpDictin = (FILE *) 0, *WimaxasncpDictout = (FILE *) 0;

typedef int yy_state_type;

extern int WimaxasncpDictlineno;

int WimaxasncpDictlineno = 1;

extern char *WimaxasncpDicttext;
#define yytext_ptr WimaxasncpDicttext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up WimaxasncpDicttext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	WimaxasncpDictleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 61
#define YY_END_OF_BUFFER 62
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[333] =
    {   0,
        0,    0,   24,   24,    0,    0,    7,    7,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   30,   30,
       31,   31,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   62,   61,   27,   24,   24,   27,
       27,   27,   20,   26,   21,   27,    4,    4,   61,    4,
        7,    8,   16,   61,   61,   18,   61,   29,   30,   30,
       30,   30,   61,   31,   31,   31,   31,   61,   38,   33,
       35,   37,   39,   40,   60,   60,   61,   61,   61,   41,

       41,   61,   61,   55,   61,   61,   61,   50,   61,   61,
       61,   61,   13,   13,   61,   13,   13,   13,   10,   12,
       24,    0,   20,   26,   21,    0,    0,   25,    0,   22,
       20,    0,   23,    6,   26,   21,    0,    2,    0,    0,
        0,    7,    8,   16,    0,    0,    0,   18,    0,   19,
       29,   30,   30,   30,   30,    0,   31,   31,   31,   31,
        0,   38,   33,   35,   37,   39,    0,    0,    0,    0,
        0,    0,   42,    0,   59,   56,    0,    0,   51,    0,
        0,    0,    0,    0,    0,    0,    0,   14,    0,    0,
       10,   12,   28,   22,    0,    0,    0,   23,    6,    2,

        5,    0,   19,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   14,    0,    0,    3,
        0,    0,    5,    0,    0,    0,    0,   44,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        3,    0,    0,    0,    0,    0,    0,    0,   52,   59,
       59,    0,    0,   59,    0,   59,    0,    9,    0,    0,
        0,    0,    0,    0,    0,   57,   54,   53,    0,    0,
       45,   59,   47,    0,    0,    0,    0,    0,   17,    0,
        0,    0,    0,    0,   49,    0,   11,    0,   15,    0,
        0,    0,   59,    0,    0,   15,    0,    0,    0,   48,

        0,    0,    1,    0,    0,    0,    0,    1,    0,    0,
        0,    0,    0,   43,    0,   59,    0,   58,   46,    0,
        0,    0,    0,    0,    0,    0,   36,    0,   34,    0,
       32,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    5,    6,    1,    1,    1,    7,    1,    8,
        9,    1,    1,    1,   10,    1,   11,   12,   13,   14,
       15,   16,   16,   17,   16,   18,   16,    1,   19,   20,
       21,   22,   23,    1,   24,   25,   26,   27,   28,   29,
       30,   30,   31,   30,   32,   33,   34,   35,   36,   37,
       30,   38,   39,   40,   41,   42,   43,   44,   45,   30,
       46,    1,   47,    1,   48,    1,   49,   50,   51,   52,

       53,   29,   30,   30,   54,   30,   55,   56,   57,   58,
       59,   60,   30,   61,   62,   63,   64,   65,   66,   67,
       68,   30,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    1,    1,    1,    2,    1,    1,    1,    3,
        1,    3,    3,    3,    3,    3,    3,    3,    1,    1,
        4,    1,    1,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    1,    1,    1,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3,    3,    3,
        3,    3,    3,    3,    3,    3,    3,    3
    } ;

static yyconst flex_int16_t yy_base[359] =
    {   0,
        0,    0,    0,    6,   21,   30,   53,  101,  149,  197,
       75,   78,  639,  638,  607,  594,  591,  556,  236,    0,
      293,    0,  116,  164,  212,  257,  281,  314,  552,  548,
      540,  536,   15,   16,    9,   23,    0,    0,  508,  489,
       35,   36,  346,  404,  452,  505,  399,  415,  502,  471,
      463,  455,    0,    0,  448, 1090, 1090,  464,  479,  439,
        0,  418,  359,   42,   46,   63, 1090,   84,   87,  427,
       66,    0,    0,  229,   47,    0,  139,    0,  171,  557,
       49,  521,   65,  222,  613,   69,  535,  136, 1090,  321,
      361,  371,    0, 1090, 1090,  112,    0,  152,  405, 1090,

      423,  370,  368, 1090,  154,  291,  358, 1090,  393,  411,
      226,  256, 1090,  557,  591,  334,  214,  232,    0,    0,
      632,  319,  518,  207,  356,  491,  308, 1090,  294,  396,
      440,  622,  469,  494,  503,  515,  574,  588,  601,  294,
      270,  613,    0,    0,  616,   99,  216,    0,  665,  656,
        0,  676,  392,    0,    0,  419,  683,  421,    0,    0,
      447, 1090,  690,  697,  704,    0,  458,  273,  469,  503,
      529,  278, 1090,  237, 1090, 1090,  503,  627, 1090,  702,
      703,  704,  705,  727,  219,  343,  371,  668,  553,  699,
        0,    0, 1090,  679,  213,  697,  699,  741,  744,  764,

      768,  695,  771,  627,  701,  707,  698,  721,  735,  757,
      758,  759,  762,  763,  768,  769,  798,  802,  757,  805,
      761,  763,  825,  786,  771,  777,  794, 1090,  782,  791,
      201,  191,  809,  811,  186,  813,  173,  848,  840,  803,
      851,  795,  806,  823,  835,  831,  823,  171, 1090,  185,
      168,  843,  844,  156,  125,  129,  875, 1090,  885,  822,
      828,  891,  837,  846,  861, 1090, 1090, 1090,  862,  880,
     1090,  121, 1090,  900,  905,  873,  867,  916, 1090,  878,
      879,  880,  105,  903, 1090,  923, 1090,  900,  928,  908,
      914,  906,  105,  921,   52,  942,  910,  910,  925, 1090,

      929,   49,  952,   36,  912,  920,  941,  965,  935,   61,
      916,   50,  941, 1090,   41,   46,  933, 1090, 1090,  964,
       34,   23,  157,  274,  426,  981, 1090,  984, 1090,  985,
     1090, 1090,  999, 1003, 1007, 1011, 1015, 1019, 1023, 1027,
     1031, 1035, 1039, 1043, 1047, 1051, 1055,   12,   11,    2,
     1059, 1063, 1067, 1071, 1073, 1077, 1081, 1085
    } ;

static yyconst flex_int16_t yy_def[359] =
    {   0,
      333,  333,  334,  334,  335,  335,  336,  336,  337,  337,
      333,  333,  338,  338,  333,  333,  339,  339,  333,   19,
      333,   21,  333,  333,  333,  333,  333,  333,  340,  340,
      333,  333,  341,  341,  333,  333,  333,  333,  333,  333,
      342,  342,  343,  343,   44,   44,  344,  344,  345,  345,
      346,  346,  333,  333,  332,  332,  332,  332,  332,  347,
      348,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  349,  350,  332,  332,  351,  332,  352,  332,  332,
       80,   80,  332,  332,  332,   85,   85,  332,  332,  332,
      332,  332,  353,  332,  332,  332,  348,  332,  332,  332,

      354,  355,  332,  332,  355,  355,  332,  332,  355,  355,
      355,  355,  332,  332,  332,  332,  332,  332,  356,  357,
      332,  332,  332,  332,  332,  332,  347,  332,  348,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  349,  350,  332,  332,  332,  351,  332,  332,
      352,  332,   80,   82,   82,  332,  332,   85,   87,   87,
      332,  332,  332,  332,  332,  353,  332,  332,  332,  332,
      332,  354,  332,  355,  332,  332,  355,  355,  332,  355,
      355,  355,  355,  332,  332,  332,  332,  332,  332,  332,
      356,  357,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  332,  332,  332,  332,  355,
      355,  355,  355,  355,  355,  355,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      355,  355,  355,  355,  355,  355,  355,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  355,  355,  332,  355,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  355,  355,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  355,  355,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  355,  358,  332,  332,  332,  332,  332,

      355,  358,  332,  332,  332,  332,  355,  332,  332,  332,
      332,  355,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,    0,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332
    } ;

static yyconst flex_int16_t yy_nxt[1159] =
    {   0,
      332,   58,   59,   58,  144,   60,   61,   58,   59,   58,
       62,   60,   61,  143,  129,   97,   62,   56,   56,   63,
       64,   65,   68,   69,   68,   63,   64,   65,   98,   97,
       70,   68,   69,   68,   96,   96,  325,   56,   56,   70,
      101,  101,   98,  135,  135,  135,   66,  136,  136,  136,
      324,  319,   66,   56,   71,   71,   71,   56,   56,   56,
       56,   56,  318,   56,  137,  137,  137,  142,  142,  142,
      316,   56,   56,   56,   56,   56,   74,   74,   74,   74,
       74,   74,  314,  309,  138,  139,  139,  139,  139,  139,
      139,  147,  332,  140,  303,  156,  140,  303,   56,   56,

       56,   56,   71,   71,   71,   56,   56,   56,   56,   56,
      300,   56,  332,   75,  147,  332,   75,   88,  156,   56,
       56,   56,   56,   56,   89,  293,  285,   90,   90,   90,
       90,   90,   90,   90,  273,  332,   75,  161,  167,   75,
      149,  149,  149,  147,  162,  272,   56,   56,   56,   56,
       56,   56,   56,   56,   56,   56,   56,   56,  326,   56,
      150,  271,  168,  167,  327,   88,  147,   56,   56,   56,
       56,   56,   89,  268,  175,   90,   90,   90,   90,   90,
       90,   90,  152,  152,  152,  152,  152,  152,  152,  177,
      267,  169,  266,  256,   56,   56,   56,   56,   56,   56,

       56,   56,   56,   56,   56,   56,  254,   56,  135,  135,
      135,  251,  177,   88,  169,   56,   56,   56,   56,   56,
       89,  250,  220,   91,   91,   91,   91,   91,   91,   91,
      145,  145,  145,  157,  157,  157,  157,  157,  157,  157,
      188,  189,   56,   56,   56,   79,  175,   80,   81,   81,
       81,   81,   81,   81,  202,  190,  182,  175,   88,   82,
       82,   82,   82,   82,   82,   89,  189,  146,   91,   91,
       91,   91,   91,   91,   91,  328,  175,  202,   83,  182,
      190,  329,   88,  173,   82,   82,   82,   82,   82,   89,
      146,  201,   92,   92,   92,   92,   92,   92,   92,  206,

      183,   83,   84,  141,   85,   86,   86,   86,   86,   86,
       86,  175,  193,  128,  178,   88,   87,   87,   87,   87,
       87,   87,   89,  183,  206,   92,   92,   92,   92,   92,
       92,   92,  163,  163,  163,  163,  163,  163,  163,  178,
      130,   87,   87,   87,   87,   87,   56,   56,   56,   56,
       56,   56,   56,   56,   56,  188,  103,  136,  136,  136,
      131,  131,  131,  132,   56,   56,   56,  104,   56,  133,
      189,  105,  164,  164,  164,  164,  164,  164,  164,  179,
      106,  134,  165,  165,  165,  165,  165,  165,  165,  176,
      175,   56,   56,   56,  190,  189,  105,  194,  194,  194,

      114,  115,  114,  106,   56,   56,   56,   56,   56,   56,
       56,   56,   56,  175,  103,  170,  114,  115,  114,  190,
      180,  116,   56,   56,   56,  104,   56,  330,  173,  105,
      117,  175,  171,  331,  181,  332,  141,  116,  106,  130,
      118,  131,  131,  131,  128,  180,  117,  332,  161,   56,
       56,   56,  204,  117,  105,  162,  118,  171,  332,  181,
       56,  106,  107,  118,  332,  121,  121,  121,   56,  117,
      198,  198,  198,  108,  122,  204,   56,  102,  109,  118,
      121,  121,  121,  123,  124,  125,  110,  332,  205,  122,
      111,  112,  137,  137,  137,  199,  199,  199,  123,  124,

      125,  207,  102,  109,  135,  135,  135,   56,   99,  110,
      126,  205,  138,  111,  112,  107,  136,  136,  136,  131,
      131,  131,  132,  175,  207,  126,  108,   99,  133,  210,
      102,  109,  154,  154,  154,  154,  154,  154,  154,  110,
      134,   94,  208,  111,  112,   94,  159,  159,  159,  159,
      159,  159,  159,   56,  210,  102,  109,   56,  184,  184,
      184,   56,  110,  209,  332,  208,  111,  112,  153,  153,
      153,  153,  153,  153,  153,  137,  137,  137,  332,  185,
      154,  154,  154,  154,  154,  154,  209,  332,  186,  200,
      200,  200,  184,  184,  184,  138,   56,  218,  187,   77,

      155,  332,  139,  139,  139,  154,  154,  154,  154,  154,
      140,  186,   77,  185,  142,  142,  142,  145,  145,  145,
      218,  187,  186,  155,  158,  158,  158,  158,  158,  158,
      158,  195,  187,  121,  121,  121,  159,  159,  159,  159,
      159,  159,  122,   56,   56,  186,  332,  175,  196,  197,
      225,  123,  124,  125,  146,  187,  160,  203,  203,  203,
      211,  159,  159,  159,  159,  159,  149,  149,  149,  217,
      217,  217,  332,  196,  197,  225,  332,  146,  126,  160,
      194,  194,  194,  211,  332,  332,  150,  152,  152,  152,
      152,  152,  152,  152,  157,  157,  157,  157,  157,  157,

      157,  163,  163,  163,  163,  163,  163,  163,  164,  164,
      164,  164,  164,  164,  164,  165,  165,  165,  165,  165,
      165,  165,  175,  175,  175,  175,  226,  212,  184,  184,
      184,  219,  221,  222,  224,  332,  214,  227,  215,  228,
      213,  216,  198,  198,  198,  199,  199,  199,  332,  185,
      332,  226,  212,  229,  219,  221,  222,  224,  186,  214,
      227,  215,  228,  213,  216,  200,  200,  200,  187,  223,
      223,  223,  203,  203,  203,  230,  229,  175,  175,  175,
      332,  186,  175,  175,  231,  232,  242,  234,  175,  175,
      235,  187,  332,  236,  233,  332,  237,  240,  230,  217,

      217,  217,  243,  238,  238,  238,  241,  241,  241,  231,
      232,  242,  234,  244,  245,  235,  246,  233,  236,  247,
      240,  237,  239,  248,  249,  243,  223,  223,  223,  175,
      259,  175,  332,  175,  260,  252,  261,  245,  244,  246,
      255,  257,  257,  257,  247,  258,  248,  249,  253,  238,
      238,  238,  241,  241,  241,  259,  262,  260,  263,  261,
      252,  264,  265,  175,  175,  255,  276,  277,  239,  332,
      269,  253,  332,  332,  270,  280,  257,  257,  257,  262,
      258,  281,  175,  263,  264,  265,  274,  274,  274,  276,
      277,  282,  278,  278,  278,  269,  279,  270,  280,  283,

      175,  274,  274,  274,  281,  275,  286,  286,  286,  288,
      287,  289,  290,  291,  282,  292,  284,  278,  278,  278,
      275,  279,  283,  175,  286,  286,  286,  295,  287,  296,
      296,  296,  288,  297,  289,  290,  291,  298,  292,  284,
      299,  175,  294,  296,  296,  296,  304,  305,  306,  175,
      332,  301,  295,  308,  308,  308,  310,  311,  297,  313,
      315,  175,  298,  299,  307,  294,  308,  308,  308,  304,
      305,  317,  320,  306,  301,  312,  321,  332,  322,  310,
      311,  323,  326,  315,  313,  328,  330,  307,  327,  332,
      332,  329,  331,  332,  317,  320,  332,  332,  312,   56,

       56,   56,   56,   57,   57,   57,   57,   67,   67,   67,
       67,   72,   72,   72,   72,   73,   73,   73,   73,   76,
       76,   76,   76,   78,   78,   78,   78,   93,   93,   93,
       93,   95,   95,   95,   95,  100,  100,  100,  100,  102,
      102,  102,  102,  113,  113,  113,  113,  119,  119,  119,
      119,  120,  120,  120,  120,  127,  127,  127,  127,  148,
      332,  148,  148,  151,  332,  151,  151,  166,  332,  166,
      166,  172,  172,  172,  172,  174,  174,  191,  332,  191,
      191,  192,  332,  192,  192,  302,  302,  302,  302,   55,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332
    } ;

static yyconst flex_int16_t yy_chk[1159] =
    {   0,
        0,    3,    3,    3,  350,    3,    3,    4,    4,    4,
        3,    4,    4,  349,  348,   35,    4,   33,   34,    3,
        3,    3,    5,    5,    5,    4,    4,    4,   35,   36,
        5,    6,    6,    6,   33,   34,  322,   41,   42,    6,
       41,   42,   36,   64,   64,   64,    3,   65,   65,   65,
      321,  316,    4,    7,    7,    7,    7,    7,    7,    7,
        7,    7,  315,    7,   66,   66,   66,   71,   71,   71,
      312,    7,    7,    7,    7,    7,   11,   11,   11,   12,
       12,   12,  310,  304,   66,   68,   68,   68,   69,   69,
       69,   75,   81,   68,  302,   83,   69,  295,    7,    7,

        7,    8,    8,    8,    8,    8,    8,    8,    8,    8,
      293,    8,   86,   11,   75,   81,   12,   23,   83,    8,
        8,    8,    8,    8,   23,  283,  272,   23,   23,   23,
       23,   23,   23,   23,  256,   86,   11,   88,   96,   12,
       77,   77,   77,  146,   88,  255,    8,    8,    8,    9,
        9,    9,    9,    9,    9,    9,    9,    9,  323,    9,
       77,  254,   98,   96,  323,   24,  146,    9,    9,    9,
        9,    9,   24,  251,  105,   24,   24,   24,   24,   24,
       24,   24,   79,   79,   79,   79,   79,   79,   79,  105,
      250,   98,  248,  237,    9,    9,    9,   10,   10,   10,

       10,   10,   10,   10,   10,   10,  235,   10,  124,  124,
      124,  232,  105,   25,   98,   10,   10,   10,   10,   10,
       25,  231,  195,   25,   25,   25,   25,   25,   25,   25,
       74,   74,   74,   84,   84,   84,   84,   84,   84,   84,
      185,  117,   10,   10,   10,   19,  111,   19,   19,   19,
       19,   19,   19,   19,  147,  118,  111,  174,   26,   19,
       19,   19,   19,   19,   19,   26,  117,   74,   26,   26,
       26,   26,   26,   26,   26,  324,  112,  147,   19,  111,
      118,  324,   27,  172,   19,   19,   19,   19,   19,   27,
       74,  141,   27,   27,   27,   27,   27,   27,   27,  168,

      112,   19,   21,  140,   21,   21,   21,   21,   21,   21,
       21,  106,  129,  127,  106,   28,   21,   21,   21,   21,
       21,   21,   28,  112,  168,   28,   28,   28,   28,   28,
       28,   28,   90,   90,   90,   90,   90,   90,   90,  106,
      122,   21,   21,   21,   21,   21,   43,   43,   43,   43,
       43,   43,   43,   43,   43,  116,   43,  125,  125,  125,
       63,   63,   63,   63,   43,   43,   43,   43,   43,   63,
      186,   43,   91,   91,   91,   91,   91,   91,   91,  107,
       43,   63,   92,   92,   92,   92,   92,   92,   92,  103,
      102,   43,   43,   43,  187,  186,   43,  130,  130,  130,

       47,   47,   47,   43,   44,   44,   44,   44,   44,   44,
       44,   44,   44,  109,   44,   99,   48,   48,   48,  187,
      109,   47,   44,   44,   44,   44,   44,  325,  101,   44,
       47,  110,   99,  325,  110,  153,   70,   48,   44,   62,
       47,  131,  131,  131,   60,  109,   48,   55,  161,   44,
       44,   44,  156,   47,   44,  161,   48,   99,  153,  110,
       52,   44,   45,   47,  158,   58,   58,   58,   51,   48,
      133,  133,  133,   45,   58,  156,   50,   45,   45,   48,
       59,   59,   59,   58,   58,   58,   45,  158,  167,   59,
       45,   45,  126,  126,  126,  134,  134,  134,   59,   59,

       59,  169,   45,   45,  135,  135,  135,   49,   40,   45,
       58,  167,  126,   45,   45,   46,  136,  136,  136,  123,
      123,  123,  123,  177,  169,   59,   46,   39,  123,  177,
       46,   46,   82,   82,   82,   82,   82,   82,   82,   46,
      123,   32,  170,   46,   46,   31,   87,   87,   87,   87,
       87,   87,   87,   30,  177,   46,   46,   29,  114,  114,
      114,   18,   46,  171,   82,  170,   46,   46,   80,   80,
       80,   80,   80,   80,   80,  137,  137,  137,   87,  114,
       80,   80,   80,   80,   80,   80,  171,   82,  114,  138,
      138,  138,  115,  115,  115,  137,   17,  189,  114,   16,

       80,   87,  139,  139,  139,   80,   80,   80,   80,   80,
      139,  114,   15,  115,  142,  142,  142,  145,  145,  145,
      189,  114,  115,   80,   85,   85,   85,   85,   85,   85,
       85,  132,  115,  121,  121,  121,   85,   85,   85,   85,
       85,   85,  121,   14,   13,  115,    0,  178,  132,  132,
      204,  121,  121,  121,  145,  115,   85,  150,  150,  150,
      178,   85,   85,   85,   85,   85,  149,  149,  149,  188,
      188,  188,    0,  132,  132,  204,    0,  145,  121,   85,
      194,  194,  194,  178,    0,    0,  149,  152,  152,  152,
      152,  152,  152,  152,  157,  157,  157,  157,  157,  157,

      157,  163,  163,  163,  163,  163,  163,  163,  164,  164,
      164,  164,  164,  164,  164,  165,  165,  165,  165,  165,
      165,  165,  180,  181,  182,  183,  205,  180,  184,  184,
      184,  190,  196,  197,  202,    0,  181,  206,  182,  207,
      180,  183,  198,  198,  198,  199,  199,  199,    0,  184,
        0,  205,  180,  208,  190,  196,  197,  202,  184,  181,
      206,  182,  207,  180,  183,  200,  200,  200,  184,  201,
      201,  201,  203,  203,  203,  209,  208,  210,  211,  212,
        0,  184,  213,  214,  210,  211,  221,  213,  215,  216,
      214,  184,    0,  215,  212,    0,  216,  219,  209,  217,

      217,  217,  222,  218,  218,  218,  220,  220,  220,  210,
      211,  221,  213,  224,  225,  214,  226,  212,  215,  227,
      219,  216,  218,  229,  230,  222,  223,  223,  223,  233,
      240,  234,    0,  236,  242,  233,  243,  225,  224,  226,
      236,  239,  239,  239,  227,  239,  229,  230,  234,  238,
      238,  238,  241,  241,  241,  240,  244,  242,  245,  243,
      233,  246,  247,  252,  253,  236,  260,  261,  238,    0,
      252,  234,    0,    0,  253,  263,  257,  257,  257,  244,
      257,  264,  269,  245,  246,  247,  259,  259,  259,  260,
      261,  265,  262,  262,  262,  252,  262,  253,  263,  269,

      270,  274,  274,  274,  264,  259,  275,  275,  275,  276,
      275,  277,  280,  281,  265,  282,  270,  278,  278,  278,
      274,  278,  269,  284,  286,  286,  286,  288,  286,  289,
      289,  289,  276,  290,  277,  280,  281,  291,  282,  270,
      292,  294,  284,  296,  296,  296,  297,  298,  299,  301,
        0,  294,  288,  303,  303,  303,  305,  306,  290,  309,
      311,  307,  291,  292,  301,  284,  308,  308,  308,  297,
      298,  313,  317,  299,  294,  307,  320,    0,  320,  305,
      306,  320,  326,  311,  309,  328,  330,  301,  326,    0,
        0,  328,  330,    0,  313,  317,    0,    0,  307,  333,

      333,  333,  333,  334,  334,  334,  334,  335,  335,  335,
      335,  336,  336,  336,  336,  337,  337,  337,  337,  338,
      338,  338,  338,  339,  339,  339,  339,  340,  340,  340,
      340,  341,  341,  341,  341,  342,  342,  342,  342,  343,
      343,  343,  343,  344,  344,  344,  344,  345,  345,  345,
      345,  346,  346,  346,  346,  347,  347,  347,  347,  351,
        0,  351,  351,  352,    0,  352,  352,  353,    0,  353,
      353,  354,  354,  354,  354,  355,  355,  356,    0,  356,
      356,  357,    0,  357,  357,  358,  358,  358,  358,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,

      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332,  332,  332,
      332,  332,  332,  332,  332,  332,  332,  332
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int WimaxasncpDict_flex_debug;
int WimaxasncpDict_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *WimaxasncpDicttext;
#line 1 "wimaxasncp_dict.l"
/*
 * We don't use unput, so don't generate code for it.
 */
/*
 * We don't read from the terminal.
 */
/*
 * The language we're scanning is case-insensitive.
 */
/*
 * We use start condition stacks.
 */
/*
 * Prefix scanner routines with "WimaxasncpDict" rather than "yy", so this
 * scanner can coexist with other scanners.
 */
#line 30 "wimaxasncp_dict.l"
	/*
	 ** wimaxasncp_dict.h
	 ** WIMAXASNCP Dictionary Import Routines
	 **
	 ** $Id: wimaxasncp_dict.l 34919 2010-11-17 03:16:30Z morriss $
	 **
	 ** (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
	 ** (c) 2007, Stephen Croll <stephen.d.croll@gmail.com>
	 **
	 ** This library is free software; you can redistribute it and/or
	 ** modify it under the terms of the GNU Library General Public
	 ** License as published by the Free Software Foundation; either
	 ** version 2 of the License, or (at your option) any later version.
	 **
	 ** This library is distributed in the hope that it will be useful,
	 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
	 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
	 ** Library General Public License for more details.
	 **
	 ** You should have received a copy of the GNU Library General Public
	 ** License along with this library; if not, write to the Free Software
	 ** Foundation, Inc., 51 Franklin Street, Fifth Floor,
	 ** Boston, MA  02110-1301, USA.
	 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <glib.h>
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
#include <stdarg.h>
#include <epan/emem.h>
#include <epan/value_string.h>
#include <epan/packet.h>	/* array_length */
#include <wsutil/file_util.h>

#include "wimaxasncp_dict.h"
#include "wimaxasncp_dict_lex.h"

typedef struct entity_t {
	gchar *name;
	gchar *file;
	struct entity_t *next;
} entity_t;

#define ATTR_UINT(cont) do { D(("attr_uint " #cont "\t" )); attr_uint = &(cont); yy_push_state(GET_UINT_ATTR); } while(0)
#define ATTR_UINT16(cont) do { D(("attr_uint16 " #cont "\t" )); attr_uint16 = &(cont); yy_push_state(GET_UINT16_ATTR); } while(0)
#define ATTR_STR(cont) do { D(("attr_str " #cont "\t" )); attr_str = &(cont); yy_push_state(GET_ATTR); } while(0)
#define ATTR_DECODER(cont) do { D(("attr_decoder " #cont "\t" )); attr_uint = &(cont); yy_push_state(GET_DECODER_ATTR); } while(0)
#define WIMAXASNCP_IGNORE() do { D(("ignore: %s\t",WimaxasncpDicttext)); yy_push_state(IGNORE_ATTR); } while(0)

#define D(args) wimaxasncp_dict_debug args

#define MAX_INCLUDE_DEPTH 10
#define YY_INPUT(buf,result,max_size) { result = current_yyinput(buf,max_size); }
#define ECHO
#define APPEND(txt,len) append_to_buffer(txt,len)

static entity_t ents;
static YY_BUFFER_STATE include_stack[MAX_INCLUDE_DEPTH];
static int include_stack_ptr = 0;
static size_t (*current_yyinput)(gchar*,size_t);
static const gchar *sys_dir;
static wimaxasncp_dict_t *dict;
static wimaxasncp_dict_tlv_t *tlv;
static wimaxasncp_dict_enum_t *enumitem;
static wimaxasncp_dict_xmlpi_t *xmlpi;

static wimaxasncp_dict_tlv_t *last_tlv;
static wimaxasncp_dict_enum_t *last_enumitem;
static wimaxasncp_dict_xmlpi_t *last_xmlpi;

static gchar **attr_str;
static guint *attr_uint;
static gint16 *attr_uint16;

static guint wimaxasncp_bits(guint bits, char *n);
static gint wimaxasncp_decode_type(const gchar *name);
static void wimaxasncp_dict_debug(const gchar *fmt, ...);
static void append_to_buffer(gchar *txt, int len);
static FILE *wimaxasncp_dict_open(const gchar*, const gchar*);

static GString *dict_error = NULL;







#line 959 "wimaxasncp_dict.c"

#define INITIAL 0
#define LOADING 1
#define LOADING_COMMENT 2
#define LOADING_XMLPI 3
#define ENTITY 4
#define GET_SYSTEM 5
#define GET_FILE 6
#define END_ENTITY 7
#define GET_ATTR 8
#define GET_UINT_ATTR 9
#define GET_UINT16_ATTR 10
#define BIT32 11
#define BIT16 12
#define BIT8 13
#define GET_DECODER_ATTR 14
#define END_ATTR 15
#define OUTSIDE 16
#define IN_DICT 17
#define IN_APPL 18
#define IN_TLV 19
#define IGNORE_ATTR 20
#define ENUM_ATTRS 21
#define TLV_ATTRS 22
#define XMLPI_ATTRS 23
#define XMLPI_GETKEY 24
#define XMLPI_GETVAL 25
#define XMLPI_ENDATTR 26

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int WimaxasncpDictlex_destroy (void );

int WimaxasncpDictget_debug (void );

void WimaxasncpDictset_debug (int debug_flag  );

YY_EXTRA_TYPE WimaxasncpDictget_extra (void );

void WimaxasncpDictset_extra (YY_EXTRA_TYPE user_defined  );

FILE *WimaxasncpDictget_in (void );

void WimaxasncpDictset_in  (FILE * in_str  );

FILE *WimaxasncpDictget_out (void );

void WimaxasncpDictset_out  (FILE * out_str  );

int WimaxasncpDictget_leng (void );

char *WimaxasncpDictget_text (void );

int WimaxasncpDictget_lineno (void );

void WimaxasncpDictset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int WimaxasncpDictwrap (void );
#else
extern int WimaxasncpDictwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

        static int yy_start_stack_ptr = 0;
        static int yy_start_stack_depth = 0;
        static int *yy_start_stack = NULL;
    
    static void yy_push_state (int new_state );
    
    static void yy_pop_state (void );
    
    static int yy_top_state (void );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( WimaxasncpDicttext, WimaxasncpDictleng, 1, WimaxasncpDictout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( WimaxasncpDictin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( WimaxasncpDictin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, WimaxasncpDictin))==0 && ferror(WimaxasncpDictin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(WimaxasncpDictin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int WimaxasncpDictlex (void);

#define YY_DECL int WimaxasncpDictlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after WimaxasncpDicttext and WimaxasncpDictleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 184 "wimaxasncp_dict.l"

#line 1182 "wimaxasncp_dict.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! WimaxasncpDictin )
			WimaxasncpDictin = stdin;

		if ( ! WimaxasncpDictout )
			WimaxasncpDictout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			WimaxasncpDictensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE );
		}

		WimaxasncpDict_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of WimaxasncpDicttext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 333 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 332 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 185 "wimaxasncp_dict.l"
;
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 186 "wimaxasncp_dict.l"
;
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 188 "wimaxasncp_dict.l"
BEGIN LOADING_COMMENT;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 189 "wimaxasncp_dict.l"
;
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 190 "wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 6:
/* rule 6 can match eol */
YY_RULE_SETUP
#line 192 "wimaxasncp_dict.l"
BEGIN LOADING_XMLPI;
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 193 "wimaxasncp_dict.l"
;
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 194 "wimaxasncp_dict.l"
{
	xmlpi = g_malloc(sizeof(wimaxasncp_dict_xmlpi_t));
	xmlpi->name = g_strdup(WimaxasncpDicttext);
	xmlpi->key = NULL;
	xmlpi->value = NULL;
	xmlpi->next = NULL;

	if (!dict->xmlpis) last_xmlpi = dict->xmlpis = xmlpi;
	else last_xmlpi = last_xmlpi->next = xmlpi;

	BEGIN XMLPI_ATTRS;
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 207 "wimaxasncp_dict.l"
BEGIN XMLPI_GETKEY;
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 208 "wimaxasncp_dict.l"
{ xmlpi->key = g_strdup(WimaxasncpDicttext); BEGIN XMLPI_ATTRS; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 210 "wimaxasncp_dict.l"
BEGIN XMLPI_GETVAL;
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 211 "wimaxasncp_dict.l"
{ xmlpi->value = g_strdup(WimaxasncpDicttext); BEGIN XMLPI_ATTRS; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 213 "wimaxasncp_dict.l"

	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 214 "wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 217 "wimaxasncp_dict.l"
BEGIN ENTITY;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 218 "wimaxasncp_dict.l"
{
	entity_t *e = g_malloc(sizeof(entity_t));
	D(("ENTITY: %s\n",WimaxasncpDicttext));
	e->name = g_strdup(WimaxasncpDicttext);
	e->next = ents.next;
	ents.next = e;
	BEGIN GET_SYSTEM;
};
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 226 "wimaxasncp_dict.l"
BEGIN GET_FILE;
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 227 "wimaxasncp_dict.l"
{
	D(("GET_FILE: %s\n",WimaxasncpDicttext));
	ents.next->file = g_strdup(WimaxasncpDicttext);
	BEGIN END_ENTITY;
}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 232 "wimaxasncp_dict.l"
BEGIN LOADING;
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 234 "wimaxasncp_dict.l"
APPEND("<",1);
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 236 "wimaxasncp_dict.l"
APPEND(">",1);
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 238 "wimaxasncp_dict.l"
APPEND("/>",2);
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 240 "wimaxasncp_dict.l"
APPEND("</",2);
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 242 "wimaxasncp_dict.l"
APPEND(" ",1);
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 244 "wimaxasncp_dict.l"
APPEND(WimaxasncpDicttext,WimaxasncpDictleng);
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 246 "wimaxasncp_dict.l"
APPEND("=",1);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 248 "wimaxasncp_dict.l"
APPEND(WimaxasncpDicttext,WimaxasncpDictleng);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 250 "wimaxasncp_dict.l"
{
	gchar *p = ++WimaxasncpDicttext, *temp_str;
	entity_t* e;

	while(*p != ';') p++;

	*p = '\0';

	D(("looking for entity: %s\n",WimaxasncpDicttext));

	if ( include_stack_ptr >= MAX_INCLUDE_DEPTH ) {
		dict_error = g_string_append(
			dict_error, "included files nested too deeply\n");
		yyterminate();
	}

	include_stack[include_stack_ptr++] = YY_CURRENT_BUFFER;


	for (e = ents.next; e; e = e->next) {
		if (strcmp(e->name,WimaxasncpDicttext) == 0) {
			WimaxasncpDictin = wimaxasncp_dict_open(sys_dir,e->file);
			D(("entity: %s filename: %s WimaxasncpDictin: %p\n",e->name,e->file,WimaxasncpDictin));
			if (!WimaxasncpDictin) {
				yyterminate();
			} else {
				WimaxasncpDict_switch_to_buffer(WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE ) );
			}
			break;
		}
	}

	if (!e) {
		temp_str = g_strdup_printf(
			"cannot find entity: '%s'\n", e->name);
		dict_error = g_string_append(dict_error, temp_str);
		g_free(temp_str);
		yyterminate();
	}

}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(LOADING):
case YY_STATE_EOF(LOADING_COMMENT):
case YY_STATE_EOF(LOADING_XMLPI):
case YY_STATE_EOF(ENTITY):
case YY_STATE_EOF(GET_SYSTEM):
case YY_STATE_EOF(GET_FILE):
case YY_STATE_EOF(END_ENTITY):
case YY_STATE_EOF(GET_ATTR):
case YY_STATE_EOF(GET_UINT_ATTR):
case YY_STATE_EOF(GET_UINT16_ATTR):
case YY_STATE_EOF(BIT32):
case YY_STATE_EOF(BIT16):
case YY_STATE_EOF(BIT8):
case YY_STATE_EOF(GET_DECODER_ATTR):
case YY_STATE_EOF(END_ATTR):
case YY_STATE_EOF(OUTSIDE):
case YY_STATE_EOF(IN_DICT):
case YY_STATE_EOF(IN_APPL):
case YY_STATE_EOF(IN_TLV):
case YY_STATE_EOF(IGNORE_ATTR):
case YY_STATE_EOF(ENUM_ATTRS):
case YY_STATE_EOF(TLV_ATTRS):
case YY_STATE_EOF(XMLPI_ATTRS):
case YY_STATE_EOF(XMLPI_GETKEY):
case YY_STATE_EOF(XMLPI_GETVAL):
case YY_STATE_EOF(XMLPI_ENDATTR):
#line 292 "wimaxasncp_dict.l"
{
	if (!WimaxasncpDictin) yyterminate();

	fclose(WimaxasncpDictin);
	D(("closing: %p %i\n",WimaxasncpDictin,include_stack_ptr));

	if ( --include_stack_ptr < 0 ) {
		D(("DONE READING\n"));
		WimaxasncpDictin = NULL;
		yyterminate();
	} else {
		WimaxasncpDict_delete_buffer(YY_CURRENT_BUFFER );
		WimaxasncpDict_switch_to_buffer(include_stack[include_stack_ptr]);
		BEGIN LOADING;
	}
}
	YY_BREAK
case 29:
/* rule 29 can match eol */
YY_RULE_SETUP
#line 310 "wimaxasncp_dict.l"
{
	*attr_str = g_strdup(WimaxasncpDicttext);
	D(("%s\n",WimaxasncpDicttext));
	attr_str = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 317 "wimaxasncp_dict.l"
{
	*attr_uint = strtoul(WimaxasncpDicttext,NULL,0);
	D(("%s\n",WimaxasncpDicttext););
	attr_uint = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 324 "wimaxasncp_dict.l"
{
	*attr_uint16 = (gint16) strtol(WimaxasncpDicttext,NULL,0);
	D(("%s\n",WimaxasncpDicttext););
	attr_uint16 = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 331 "wimaxasncp_dict.l"
{ BEGIN BIT32; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 333 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_bits(32, WimaxasncpDicttext);
	D(("WIMAXASNCP_BIT32(%s)\n",WimaxasncpDicttext););
	attr_uint = NULL;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 339 "wimaxasncp_dict.l"
{ BEGIN BIT16; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 341 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_bits(16, WimaxasncpDicttext);
	D(("WIMAXASNCP_BIT16(%s)\n",WimaxasncpDicttext););
	attr_uint = NULL;
}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 347 "wimaxasncp_dict.l"
{ BEGIN BIT8; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 349 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_bits(8, WimaxasncpDicttext);
	D(("WIMAXASNCP_BIT8(%s)\n",WimaxasncpDicttext););
	attr_uint = NULL;
}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 355 "wimaxasncp_dict.l"
{ BEGIN END_ATTR; }
	YY_BREAK
case 39:
/* rule 39 can match eol */
YY_RULE_SETUP
#line 357 "wimaxasncp_dict.l"
{
	*attr_uint = wimaxasncp_decode_type(WimaxasncpDicttext);
	D(("%s\n",WimaxasncpDicttext));
	attr_uint = NULL;
	BEGIN END_ATTR;
}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 364 "wimaxasncp_dict.l"
{	yy_pop_state(); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 366 "wimaxasncp_dict.l"
{
	/* XXX: should go?*/
	D(("{%s}",WimaxasncpDicttext));
}
	YY_BREAK
case 42:
/* rule 42 can match eol */
YY_RULE_SETUP
#line 371 "wimaxasncp_dict.l"
{
	D(("=>%s<=\n",WimaxasncpDicttext));
	yy_pop_state();
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 376 "wimaxasncp_dict.l"
{
	D(("dictionary_start\n"));

	BEGIN IN_DICT;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 382 "wimaxasncp_dict.l"
{
	D(("tlv_start\n"));

	tlv = g_malloc(sizeof(wimaxasncp_dict_tlv_t));
	tlv->type = 0;
	tlv->name = NULL;
	tlv->description = NULL;
	tlv->decoder = 0;
	tlv->since = 0;
	tlv->hf_root = -1;
	tlv->hf_value = -1;
	tlv->hf_ipv4 = -1;
	tlv->hf_ipv6 = -1;
	tlv->hf_bsid = -1;
	tlv->hf_protocol = -1;
	tlv->hf_port_low = -1;
	tlv->hf_port_high = -1;
	tlv->hf_ipv4_mask = -1;
	tlv->hf_ipv6_mask = -1;
	tlv->hf_vendor_id = -1;
	tlv->hf_vendor_rest_of_info = -1;
	tlv->enum_vs = NULL;
	tlv->enums = NULL;
	tlv->next = NULL;

	if (! dict->tlvs ) last_tlv = dict->tlvs = tlv;
	else last_tlv = last_tlv->next = tlv;

	BEGIN TLV_ATTRS;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 413 "wimaxasncp_dict.l"
{ ATTR_STR(tlv->name); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 414 "wimaxasncp_dict.l"
{ ATTR_STR(tlv->description); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 415 "wimaxasncp_dict.l"
{ ATTR_UINT16(tlv->type); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 416 "wimaxasncp_dict.l"
{ ATTR_DECODER(tlv->decoder); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 417 "wimaxasncp_dict.l"
{ ATTR_UINT(tlv->since); }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 418 "wimaxasncp_dict.l"
{ BEGIN IN_TLV;	 }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 419 "wimaxasncp_dict.l"
{ BEGIN IN_DICT; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 422 "wimaxasncp_dict.l"
{
	D(("enum_start\n"));

	enumitem = g_malloc(sizeof(wimaxasncp_dict_enum_t));
	enumitem->name = NULL;
	enumitem->code = 0;
	enumitem->next = NULL;

	if (!tlv->enums) last_enumitem = tlv->enums = enumitem;
	else last_enumitem = last_enumitem->next = enumitem;

	BEGIN ENUM_ATTRS;
}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 437 "wimaxasncp_dict.l"
{ ATTR_STR(enumitem->name); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 438 "wimaxasncp_dict.l"
{ ATTR_UINT(enumitem->code); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 440 "wimaxasncp_dict.l"
{ BEGIN IN_TLV; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 441 "wimaxasncp_dict.l"
{ BEGIN IN_TLV; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 443 "wimaxasncp_dict.l"
{ D(("tlv_end")); BEGIN IN_DICT; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 445 "wimaxasncp_dict.l"
{
	yyterminate();
}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 449 "wimaxasncp_dict.l"
WIMAXASNCP_IGNORE();
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 451 "wimaxasncp_dict.l"
;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 458 "wimaxasncp_dict.l"
ECHO;
	YY_BREAK
#line 1783 "wimaxasncp_dict.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed WimaxasncpDictin at a new source and called
			 * WimaxasncpDictlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = WimaxasncpDictin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( WimaxasncpDictwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * WimaxasncpDicttext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of WimaxasncpDictlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					WimaxasncpDictrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			WimaxasncpDictrestart(WimaxasncpDictin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) WimaxasncpDictrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 333 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 333 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 332);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					WimaxasncpDictrestart(WimaxasncpDictin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( WimaxasncpDictwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve WimaxasncpDicttext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void WimaxasncpDictrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        WimaxasncpDictensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            WimaxasncpDict_create_buffer(WimaxasncpDictin,YY_BUF_SIZE );
	}

	WimaxasncpDict_init_buffer(YY_CURRENT_BUFFER,input_file );
	WimaxasncpDict_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void WimaxasncpDict_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		WimaxasncpDictpop_buffer_state();
	 *		WimaxasncpDictpush_buffer_state(new_buffer);
     */
	WimaxasncpDictensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	WimaxasncpDict_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (WimaxasncpDictwrap()) processing, but the only time this flag
	 * is looked at is after WimaxasncpDictwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void WimaxasncpDict_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	WimaxasncpDictin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE WimaxasncpDict_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) WimaxasncpDictalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) WimaxasncpDictalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_create_buffer()" );

	b->yy_is_our_buffer = 1;

	WimaxasncpDict_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with WimaxasncpDict_create_buffer()
 * 
 */
    void WimaxasncpDict_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		WimaxasncpDictfree((void *) b->yy_ch_buf  );

	WimaxasncpDictfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a WimaxasncpDictrestart() or at EOF.
 */
    static void WimaxasncpDict_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	WimaxasncpDict_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then WimaxasncpDict_init_buffer was _probably_
     * called from WimaxasncpDictrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void WimaxasncpDict_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		WimaxasncpDict_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void WimaxasncpDictpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	WimaxasncpDictensure_buffer_stack();

	/* This block is copied from WimaxasncpDict_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from WimaxasncpDict_switch_to_buffer. */
	WimaxasncpDict_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void WimaxasncpDictpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	WimaxasncpDict_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		WimaxasncpDict_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void WimaxasncpDictensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)WimaxasncpDictalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDictensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)WimaxasncpDictrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDictensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE WimaxasncpDict_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) WimaxasncpDictalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	WimaxasncpDict_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to WimaxasncpDictlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       WimaxasncpDict_scan_bytes() instead.
 */
YY_BUFFER_STATE WimaxasncpDict_scan_string (yyconst char * yystr )
{
    
	return WimaxasncpDict_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to WimaxasncpDictlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE WimaxasncpDict_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) WimaxasncpDictalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in WimaxasncpDict_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = WimaxasncpDict_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in WimaxasncpDict_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state )
{
    	if ( (yy_start_stack_ptr) >= (yy_start_stack_depth) )
		{
		yy_size_t new_size;

		(yy_start_stack_depth) += YY_START_STACK_INCR;
		new_size = (yy_start_stack_depth) * sizeof( int );

		if ( ! (yy_start_stack) )
			(yy_start_stack) = (int *) WimaxasncpDictalloc(new_size  );

		else
			(yy_start_stack) = (int *) WimaxasncpDictrealloc((void *) (yy_start_stack),new_size  );

		if ( ! (yy_start_stack) )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	(yy_start_stack)[(yy_start_stack_ptr)++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (void)
{
    	if ( --(yy_start_stack_ptr) < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN((yy_start_stack)[(yy_start_stack_ptr)]);
}

    static int yy_top_state  (void)
{
    	return (yy_start_stack)[(yy_start_stack_ptr) - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up WimaxasncpDicttext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		WimaxasncpDicttext[WimaxasncpDictleng] = (yy_hold_char); \
		(yy_c_buf_p) = WimaxasncpDicttext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		WimaxasncpDictleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int WimaxasncpDictget_lineno  (void)
{
        
    return WimaxasncpDictlineno;
}

/** Get the input stream.
 * 
 */
FILE *WimaxasncpDictget_in  (void)
{
        return WimaxasncpDictin;
}

/** Get the output stream.
 * 
 */
FILE *WimaxasncpDictget_out  (void)
{
        return WimaxasncpDictout;
}

/** Get the length of the current token.
 * 
 */
int WimaxasncpDictget_leng  (void)
{
        return WimaxasncpDictleng;
}

/** Get the current token.
 * 
 */

char *WimaxasncpDictget_text  (void)
{
        return WimaxasncpDicttext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void WimaxasncpDictset_lineno (int  line_number )
{
    
    WimaxasncpDictlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see WimaxasncpDict_switch_to_buffer
 */
void WimaxasncpDictset_in (FILE *  in_str )
{
        WimaxasncpDictin = in_str ;
}

void WimaxasncpDictset_out (FILE *  out_str )
{
        WimaxasncpDictout = out_str ;
}

int WimaxasncpDictget_debug  (void)
{
        return WimaxasncpDict_flex_debug;
}

void WimaxasncpDictset_debug (int  bdebug )
{
        WimaxasncpDict_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from WimaxasncpDictlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_start_stack_ptr) = 0;
    (yy_start_stack_depth) = 0;
    (yy_start_stack) =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    WimaxasncpDictin = stdin;
    WimaxasncpDictout = stdout;
#else
    WimaxasncpDictin = (FILE *) 0;
    WimaxasncpDictout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * WimaxasncpDictlex_init()
     */
    return 0;
}

/* WimaxasncpDictlex_destroy is for both reentrant and non-reentrant scanners. */
int WimaxasncpDictlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		WimaxasncpDict_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		WimaxasncpDictpop_buffer_state();
	}

	/* Destroy the stack itself. */
	WimaxasncpDictfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Destroy the start condition stack. */
        WimaxasncpDictfree((yy_start_stack)  );
        (yy_start_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * WimaxasncpDictlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *WimaxasncpDictalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *WimaxasncpDictrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void WimaxasncpDictfree (void * ptr )
{
	free( (char *) ptr );	/* see WimaxasncpDictrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 458 "wimaxasncp_dict.l"



static int debugging  = 0;

static void wimaxasncp_dict_debug(const gchar *fmt, ...) {
	va_list ap;

	va_start(ap, fmt);
	if (debugging) vfprintf(stderr, fmt, ap);
	va_end(ap);

	fflush(stderr);
}

static guint wimaxasncp_bits(guint bits, char *n)
{
	return 1 << ((bits - 1) - (strtoul(n, NULL, 10)));
}

static const value_string wimaxasncp_decode_type_vals[] =
{
  { WIMAXASNCP_TLV_TBD,                 "WIMAXASNCP_TLV_TBD"},
  { WIMAXASNCP_TLV_COMPOUND,            "WIMAXASNCP_TLV_COMPOUND"},
  { WIMAXASNCP_TLV_BYTES,               "WIMAXASNCP_TLV_BYTES"},
  { WIMAXASNCP_TLV_ENUM8,               "WIMAXASNCP_TLV_ENUM8"},
  { WIMAXASNCP_TLV_ENUM16,              "WIMAXASNCP_TLV_ENUM16"},
  { WIMAXASNCP_TLV_ENUM32,              "WIMAXASNCP_TLV_ENUM32"},
  { WIMAXASNCP_TLV_ETHER,               "WIMAXASNCP_TLV_ETHER"},
  { WIMAXASNCP_TLV_ASCII_STRING,        "WIMAXASNCP_TLV_ASCII_STRING"},
  { WIMAXASNCP_TLV_FLAG0,               "WIMAXASNCP_TLV_FLAG0"},
  { WIMAXASNCP_TLV_BITFLAGS8,           "WIMAXASNCP_TLV_BITFLAGS8"},
  { WIMAXASNCP_TLV_BITFLAGS16,          "WIMAXASNCP_TLV_BITFLAGS16"},
  { WIMAXASNCP_TLV_BITFLAGS32,          "WIMAXASNCP_TLV_BITFLAGS32"},
  { WIMAXASNCP_TLV_ID,                  "WIMAXASNCP_TLV_ID"},
  { WIMAXASNCP_TLV_HEX8,                "WIMAXASNCP_TLV_HEX8"},
  { WIMAXASNCP_TLV_HEX16,               "WIMAXASNCP_TLV_HEX16"},
  { WIMAXASNCP_TLV_HEX32,               "WIMAXASNCP_TLV_HEX32"},
  { WIMAXASNCP_TLV_DEC8,                "WIMAXASNCP_TLV_DEC8"},
  { WIMAXASNCP_TLV_DEC16,               "WIMAXASNCP_TLV_DEC16"},
  { WIMAXASNCP_TLV_DEC32,               "WIMAXASNCP_TLV_DEC32"},
  { WIMAXASNCP_TLV_IP_ADDRESS,          "WIMAXASNCP_TLV_IP_ADDRESS"},
  { WIMAXASNCP_TLV_IPV4_ADDRESS,        "WIMAXASNCP_TLV_IPV4_ADDRESS"},
  { WIMAXASNCP_TLV_PROTOCOL_LIST,       "WIMAXASNCP_TLV_PROTOCOL_LIST"},
  { WIMAXASNCP_TLV_PORT_RANGE_LIST,     "WIMAXASNCP_TLV_PORT_RANGE_LIST"},
  { WIMAXASNCP_TLV_IP_ADDRESS_MASK_LIST,"WIMAXASNCP_TLV_IP_ADDRESS_MASK_LIST"},
  { WIMAXASNCP_TLV_EAP,                 "WIMAXASNCP_TLV_EAP"},
  { WIMAXASNCP_TLV_VENDOR_SPECIFIC,     "WIMAXASNCP_TLV_VENDOR_SPECIFIC"},
  { 0, NULL}
};

static gint wimaxasncp_decode_type(const gchar *name)
{
	gsize i;
	for (i = 0; i < array_length(wimaxasncp_decode_type_vals) - 1; ++i)
	{
		if (strcmp(name, wimaxasncp_decode_type_vals[i].strptr) == 0)
		{
			return wimaxasncp_decode_type_vals[i].value;
		}
	}

	/* not found, emit some sort of error here? */

	return WIMAXASNCP_TLV_TBD;
}

static gchar *strbuf = NULL;
static gchar *write_ptr = NULL;
static gchar *read_ptr = NULL;

static guint size_strbuf = 8192;
static guint len_strbuf = 0;

extern void wimaxasncp_dict_unused(void);
void wimaxasncp_dict_unused(void) {
	yy_top_state();
}

static void append_to_buffer(gchar *txt, int len) {

	if (strbuf == NULL) {
		read_ptr = write_ptr = strbuf = g_malloc(size_strbuf);
	}

	if ( (len_strbuf + len + 1) >= size_strbuf ) {
		read_ptr = strbuf = g_realloc(strbuf,size_strbuf *= 2);
	}

	write_ptr = strbuf + len_strbuf;
	strncpy(write_ptr,txt,len);
	len_strbuf += len;
	strbuf[len_strbuf] = '\0';
}

static size_t file_input(gchar *buf, size_t max) {
	size_t read;

	read = fread(buf,1,max,WimaxasncpDictin);

	if ( read == max ) {
		return max;
	} else if (read > 0) {
		return read;
	} else {
		return YY_NULL;
	}
}


static size_t string_input(gchar *buf, size_t max) {
	if (read_ptr >= write_ptr ) {
		return YY_NULL;
	} else if ( read_ptr + max > write_ptr ) {
		max = write_ptr - read_ptr;
	}

	memcpy(buf,read_ptr,max);
	read_ptr += max;

	return max;
}

static FILE *wimaxasncp_dict_open(
	const gchar *system_directory,
	const gchar *filename)
{
	FILE *fh;
	gchar *fname;
	if (system_directory)
	{
		int len =  strlen(system_directory) + strlen(filename)
			+ strlen(G_DIR_SEPARATOR_S) + 1;
		fname = g_malloc(len);
		g_snprintf(fname, len, "%s%s%s",
			   system_directory, G_DIR_SEPARATOR_S,filename);
	}
	else
	{
		fname = g_strdup(filename);
	}

	fh = ws_fopen(fname,"r");

	D(("fname: %s fh: %p\n",fname,fh));

	g_free(fname);


	return fh;
}

wimaxasncp_dict_t *wimaxasncp_dict_scan(
	const gchar *system_directory, const gchar *filename, int dbg,
	gchar **error) {

	entity_t *e;

	dict_error = g_string_new("");

	debugging = dbg;

	sys_dir = system_directory;

	write_ptr = NULL;
	read_ptr = NULL;

	if (dict)
	{
		wimaxasncp_dict_free(dict);
	}

	dict = g_malloc(sizeof(wimaxasncp_dict_t));
	dict->tlvs = NULL;
	dict->xmlpis = NULL;

	tlv = NULL;
	enumitem = NULL;
	xmlpi = NULL;

	last_tlv = NULL;
	last_enumitem = NULL;
	last_xmlpi = NULL;

	ents.next = NULL;

	WimaxasncpDictin = wimaxasncp_dict_open(sys_dir,filename);

	if (WimaxasncpDictin)
	{
		current_yyinput = file_input;
		BEGIN LOADING;
		WimaxasncpDictlex();

		D(("\n---------------\n%s\n------- %d -------\n",
		   strbuf, len_strbuf));

		current_yyinput = string_input;

		BEGIN OUTSIDE;
		WimaxasncpDictlex();
	}

	e = ents.next;
	while (e)
	{
		entity_t *next = e->next;
		g_free(e->name);
		g_free(e->file);
		g_free(e);
		e = next;
	}

	g_free(strbuf);
	strbuf = NULL;
	size_strbuf = 8192;

	if (dict_error->len > 0)
	{
		*error = dict_error->str;
		g_string_free(dict_error, FALSE);
	}
	else
	{
		*error = NULL;
		g_string_free(dict_error, TRUE);
	}

	return dict;
}

void wimaxasncp_dict_free(wimaxasncp_dict_t *d) {
	wimaxasncp_dict_tlv_t *t, *tn;

#define FREE_NAMEANDOBJ(n) do { if(n->name) g_free(n->name); g_free(n); } while(0)

	for (t = d->tlvs; t; t = tn) {
		wimaxasncp_dict_enum_t *e, *en;
		tn = t->next;

		for (e = t->enums; e; e = en) {
			en = e->next;
			FREE_NAMEANDOBJ(e);
		}

		if (!t->description)  g_free(t->description);
		FREE_NAMEANDOBJ(t);
	}

	g_free(d);
}

void wimaxasncp_dict_print(FILE *fh, wimaxasncp_dict_t *d) {
	wimaxasncp_dict_tlv_t *tlv;

	fprintf(fh,"\n");

	for (tlv = d->tlvs; tlv; tlv = tlv->next) {
		wimaxasncp_dict_enum_t *e;
		fprintf(fh,"TLV: %s[%u] %s[%d] %s (since %u)\n",
				tlv->name ? tlv->name : "-",
				tlv->type,
				val_to_str(tlv->decoder,
					   wimaxasncp_decode_type_vals,
					   "Unknown"),
				tlv->decoder,
				tlv->description ? tlv->description : "",
            			tlv->since);

		for (e = tlv->enums; e; e = e->next) {
			fprintf(fh,"\tEnum: %s[%u]\n",
					e->name ? e->name : "-",
					e->code);
		}
	}
}

/*
 * We want to stop processing when we get to the end of the input.
 * (%option noyywrap is not used because if used then
 * some flex versions (eg: 2.5.35) generate code which causes
 * warnings by the Windows VC compiler).
 */

int WimaxasncpDictwrap(void) {
    return 1;
}

#ifdef TEST_WIMAXASNCP_DICT_STANDALONE
int main(int argc, char **argv) {
	wimaxasncp_dict_t *d;
	gchar *dname = NULL;
	gchar *fname;
	int i = 1;

	switch (argc) {
		case 3:
			dname = argv[i++];
		case 2:
			fname = argv[i];
			break;
		default:
			fprintf(stderr,"%s: usage [dictionary_dir] dictionary_filename\n",argv[0]);
			return 1;
	}

	d = wimaxasncp_dict_scan(dname,fname,1,&dict_error);

	if (dict_error)
	{
		printf("wimaxasncp - %s", dict_error);
		g_free(dict_error);
	}

	wimaxasncp_dict_print(stdout, d);

	return 0;
}
#endif

